"""
aare-core: Z3 SMT verification engine for LLM compliance
https://github.com/aare-ai/aare-core
"""

from .formula_compiler import FormulaCompiler, OPERATORS
from .llm_parser import LLMParser
from .smt_verifier import SMTVerifier
from .ontology_loader import OntologyLoader
from .persistence import (
    VerificationStore,
    VerificationRecord,
    SQLiteStore,
    InMemoryStore,
    StorageError,
)

__version__ = "0.2.1"

__all__ = [
    "FormulaCompiler",
    "OPERATORS",
    "LLMParser",
    "SMTVerifier",
    "OntologyLoader",
    # Persistence
    "VerificationStore",
    "VerificationRecord",
    "SQLiteStore",
    "InMemoryStore",
    "StorageError",
    "__version__",
]
